function ci = getCI_bootstrap_torus(xy_coordinates,network_size,min_dist,reps)
% Calculate CI for networks with minimal neuron distance based on many
% realizations of cell body distributions.
% Okujeni 2018
%
% Clustering index based on Clark Evans
n_neurons = size(xy_coordinates,1);  % number of neurons
distmat = getDistanceTorus(xy_coordinates,network_size);
distmat = distmat + max(distmat(:))*eye(n_neurons); 
nnd_all = min(distmat);
NND_random = (1/n_neurons)*sum(nnd_all); 
NND  = nan(reps,1);
for rr=1:reps,
    xy_rand = rand(1,2).*network_size;
    for ii=1:n_neurons-1,
        mindist = 0;
        br = 0;
        while mindist < min_dist & br <=100,
            br = br+1;
            xy_rand_new = rand(1,2).*network_size;
            dxy = abs(xy_rand-repmat(xy_rand_new,size(xy_rand,1),1));
            dxy = min(cat(3,repmat(network_size,size(xy_rand,1),1)-dxy,dxy),[],3);
            mindist = min(sqrt(sum(dxy.^2,2)));
            if br == 100,
                disp('abort'); % if neuron density is too high this might happen
            end
        end
        xy_rand = [xy_rand;xy_rand_new];
    end
    distmat = getDistanceTorus(xy_rand,network_size);
    distmat = distmat + max(distmat(:))*eye(n_neurons);
    nnd_all = min(distmat);
    NND(rr) = mean(nnd_all);
end
NND_bootstrap = mean(NND);

ci = NND_random/NND_bootstrap;


